pub struct AuthMiddleware { /* private fields */ }Expand description
Middleware helper for authentication.
Implementations
Sourceimpl AuthMiddleware
impl AuthMiddleware
Sourcepub fn validate_http(
&self,
headers: &HeaderMap,
) -> Result<Option<String>, AuthError>
pub fn validate_http( &self, headers: &HeaderMap, ) -> Result<Option<String>, AuthError>
Validate HTTP headers and return actor identity (if any).
Sourcepub fn validate_grpc(
&self,
metadata: &MetadataMap,
) -> Result<Option<String>, AuthError>
pub fn validate_grpc( &self, metadata: &MetadataMap, ) -> Result<Option<String>, AuthError>
Validate gRPC metadata and return actor identity (if any).
pub fn mode(&self) -> &AuthMode
Sourcepub fn authenticated_subject(
&self,
actor: Option<&str>,
) -> Result<AuthenticatedSubject, AuthError>
pub fn authenticated_subject( &self, actor: Option<&str>, ) -> Result<AuthenticatedSubject, AuthError>
Derive the only subject that the configured local authentication mode can authorize. Call this after the request credentials have been validated; callers cannot select an arbitrary subject string.
Return the worker-facing recheck backed by this server’s local policy.