pub struct ServerLocalReadAuthorizationRecheck { /* private fields */ }Expand description
Adapts the server’s local data policy to the cluster worker boundary.
Implementations
Sourceimpl ServerLocalReadAuthorizationRecheck
impl ServerLocalReadAuthorizationRecheck
Sourcepub fn new(policy: Arc<dyn LocalReadAuthorizationPolicy>) -> Self
pub fn new(policy: Arc<dyn LocalReadAuthorizationPolicy>) -> Self
Create an adapter around the same policy used for local data access.