pub struct ReadCancellation {
pub summary: ReadExecutionSummary,
pub peer_cleanup_deliveries: usize,
pub already_terminal: bool,
}Expand description
One idempotent cancellation result for the HTTP route.
Fields
summary: ReadExecutionSummarypeer_cleanup_deliveries: usizeNumber of registered peer cleanup deliveries made by this call. It is zero for repeated cancellation and for an already-finished result.
already_terminal: boolTrait Implementations
Sourceimpl Clone for ReadCancellation
impl Clone for ReadCancellation
Sourcefn clone(&self) -> ReadCancellation
fn clone(&self) -> ReadCancellation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReadCancellation
impl Debug for ReadCancellation
impl Eq for ReadCancellation
Sourceimpl PartialEq for ReadCancellation
impl PartialEq for ReadCancellation
Sourceimpl Serialize for ReadCancellation
impl Serialize for ReadCancellation
impl StructuralPartialEq for ReadCancellation