pub struct SessionManager { /* private fields */ }Expand description
Session manager for server.
Implementations
Sourceimpl SessionManager
impl SessionManager
pub fn new(config: SessionConfig, txn_factory: TransactionFactory) -> Self
pub async fn create_session(&self) -> Result<SessionId>
Sourcepub async fn create_authenticated_session(
&self,
subject: AuthenticatedSubject,
) -> Result<SessionId>
pub async fn create_authenticated_session( &self, subject: AuthenticatedSubject, ) -> Result<SessionId>
Create a session whose authority is permanently bound to a validated remote-read delegation subject.
Sourcepub async fn authenticated_subject(
&self,
id: &SessionId,
) -> Result<AuthenticatedSubject>
pub async fn authenticated_subject( &self, id: &SessionId, ) -> Result<AuthenticatedSubject>
Return the subject bound to a remote-read session.
Ordinary legacy sessions intentionally have no subject and cannot be repurposed as a remote worker session.
pub async fn get_session(&self, id: &SessionId) -> Result<SessionSnapshot>
pub async fn begin_transaction(&self, id: &SessionId) -> Result<TxnHandle>
pub async fn get_transaction(&self, id: &SessionId) -> Result<TxnHandle>
pub async fn execute_in_session( &self, id: &SessionId, sql: &str, ) -> Result<ExecutionResult>
pub async fn commit(&self, id: &SessionId) -> Result<Vec<TableLifecycleEffect>>
pub async fn rollback( &self, id: &SessionId, ) -> Result<Vec<CatalogRollbackEffect>>
pub fn cleanup_expired(&self)